<?xml version="1.0" encoding="UTF-8"?>
<!-- VZ811v1.0_VALXSLT_564u2, 2-6-2021 -->
<xsl:stylesheet version="1.0"
xmlns:xsl="http://www.w3.org/1999/XSL/Transform"
xmlns:xsi="http://www.w3.org/2001/XMLSchema-instance"
xmlns:vbt="http://ei.vektis.nl/vz/basis/v1_0"
xmlns:vz811="http://ei.vektis.nl/vz/vz811/v1_0"
xmlns:vz812="http://ei.vektis.nl/vz/vz812/v1_0" >


 	<xsl:import href="rc0350.xslt"/>	
 	<xsl:import href="rc8028.xslt"/> 
 	<xsl:import href="rc8986.xslt"/>	
 	<xsl:import href="rc9192.xslt"/>	
	<xsl:import href="rc9196.xslt"/>	
	<xsl:import href="rc9200.xslt"/>

 	
	<!-- Uitvoer is vz812 bericht met Retourcodes. -->
	<xsl:output method="xml" version="1.0" encoding="UTF-8" indent="yes" />
	
	<xsl:variable name="Berichtcode" select="//vz811:Bericht/vz811:Header/vbt:Berichtcode" />
	<xsl:variable name="BerichtSoort" select="//vz811:Bericht/vz811:Header/vbt:BerichtSoort"/> 
	<xsl:variable name="Verzenddatum" select="translate(//vz811:Bericht/vz811:Header/vbt:Verzenddatum, '-', '')"/>
	<xsl:variable name="FinancieelJaar" select="translate(//vz811:Bericht/vz811:Context/vz811:FinancieelJaar, '-', '')"/>						


	<!-- Controleer op errors in de Header -->
	<!-- retourcode 8028: Soort bericht ontbreekt of is onjuist -->
	<xsl:variable name="rc8028">
		<xsl:call-template name="rc8028">
			<xsl:with-param name="BerichtSoort" select="$BerichtSoort" />
		</xsl:call-template>
	</xsl:variable>

	<!-- retourcode 8986: Verzenddatum moet kleiner zijn dan of gelijk zijn aan de huidige datum. -->
	<xsl:variable name="rc8986">
		<xsl:call-template name="rc8986">
			<xsl:with-param name="Verzenddatum" select="$Verzenddatum" />
			<xsl:with-param name="BerichtSoort" select="$BerichtSoort" />
		</xsl:call-template>
	</xsl:variable>

	<xsl:template match="//vz811:Bericht">
		<vz812:Bericht>
			<xsl:attribute name="xsi:schemaLocation">http://ei.vektis.nl/vz/vz812/v1_0 vz812_565.xsd</xsl:attribute>
			
			<xsl:choose>

				<!-- Geen errors in de Header, dan hele bericht als retour -->
				<xsl:when test="$rc8028='' and $rc8986=''">

					<xsl:apply-templates select="vz811:Header"/>
					<xsl:apply-templates select="vz811:Context"/>
					<xsl:apply-templates select="vz811:Overzicht"/>
					<xsl:apply-templates select="vz811:Specificatieregels"/>  
  				</xsl:when>

				<!-- Wel errors in de Header, dan alleen Header als retour -->
				<xsl:otherwise>
					<xsl:apply-templates select="vz811:Header"/>
				</xsl:otherwise>
			</xsl:choose>
				
		</vz812:Bericht>
	</xsl:template>	
		
	<xsl:template match="vz811:Header">
		<vz812:Header>
		
			<xsl:apply-templates select="vbt:BerichtSoort" mode="copy-if-exists"/>
			<xsl:apply-templates select="vbt:CrediteurOrgaan"/>
			<xsl:apply-templates select="vbt:BuitenlandsVerbindingsOrgaan"/>
			<xsl:apply-templates select="vbt:Verzenddatum" mode="copy-if-exists"/>
			<vz812:BerichtCode>565</vz812:BerichtCode>
			<xsl:apply-templates select="vz811:BerichtVersie" mode="copy-if-exists"/>
			<xsl:apply-templates select="vz811:BerichtSubVersie" mode="copy-if-exists"/>
			<xsl:apply-templates select="vz811:CrediteringReferentienummer" mode="copy-if-exists"/>
			
  	       	<vz812:Retourcodes>
					
				<xsl:copy-of select="$rc8028"/>
				<xsl:copy-of select="$rc8986"/>
					
				<!-- Wanneer de klasse correct is dan wordt een 0200 retourcode toegevoegd. -->
				<xsl:if test="$rc8028='' and $rc8986=''">
					<vbt:Retourcode>0200</vbt:Retourcode>
				</xsl:if>
				
			</vz812:Retourcodes>
  	       	
		</vz812:Header>
	</xsl:template>
		
	<xsl:template match="vz811:Context">
		<vz812:Context>
			
			<xsl:apply-templates select="vz811:DeclaratieReferentienummer" mode="copy-if-exists"/>
			
  	       	<vz812:Retourcodes>
				<!-- retourcode is altijd 0200 voor Context voor berichtcode 564 -->
					<vbt:Retourcode>0200</vbt:Retourcode>
			</vz812:Retourcodes>
  	       	
		</vz812:Context>
	</xsl:template>	
	
	<xsl:template match="vz811:Overzicht">
		<vz812:Overzicht>
			
			<xsl:apply-templates select="vz811:TotaalAantalSpecificaties" mode="copy-if-exists"/>
			<xsl:apply-templates select="vz811:TotaalBedragSpecificaties"/>
			
  	       	<vz812:Retourcodes>
				<!-- retourcode is altijd 0200 voor Overzicht voor berichtcode 564 -->
					<vbt:Retourcode>0200</vbt:Retourcode>
			</vz812:Retourcodes>
  	       	
		</vz812:Overzicht>
	</xsl:template>		
	
	<xsl:template match="vz811:Specificatieregels">
		<vz812:Specificatieregels>
			<xsl:apply-templates select="vz811:Specificatieregel"/> 
		</vz812:Specificatieregels>
	</xsl:template>	

	<xsl:template match="vz811:Specificatieregel">
		<vz812:Specificatieregel>
			
			<xsl:apply-templates select="vz811:DebiteurOrgaan"/>
			<xsl:apply-templates select="vz811:Referenties"/>
			<xsl:apply-templates select="vz811:Persoonsgegevens"/>
			<xsl:apply-templates select="vz811:TotaalBedrag"/>				
			<xsl:apply-templates select="vz811:Uitkeringen"/>	
  	       	<vz812:Retourcodes>
				
				<!-- retourcode 0350: Geboortedatum moet kleiner zijn dan verzenddatum. -->
				<xsl:variable name="rc0350">
					<xsl:call-template name="rc0350">
						<xsl:with-param name="Verzenddatum" select="$Verzenddatum"/>
						<xsl:with-param name="Geboortedatum" select="translate(vz811:Persoonsgegevens/vbt:Geboortedatum, '-', '')"/>						
					</xsl:call-template>
				</xsl:variable>
				
				<!-- retourcode 9192: Einddatum periode uitkeringen moet gelijk zijn aan of later zijn dan de begindatum periode uitkeringen. -->
				<xsl:variable name="rc9192">
					<xsl:call-template name="rc9192">
						<xsl:with-param name="Begindatum" select="translate(vz811:Uitkeringen/vz811:Periode/vbt:Begindatum, '-', '')"/>	
						<xsl:with-param name="Einddatum" select="translate(vz811:Uitkeringen/vz811:Periode/vbt:Einddatum, '-', '')"/>						
					</xsl:call-template>
				</xsl:variable>
				
				<!-- retourcode 9196: Ten minste moet MedischeZorgkosten, Medicijnkosten, Tandartskosten, LangdurigeZorgkosten, Ziekenhuisopnamekosten of OverigeKosten voorkomen. -->
				<xsl:variable name="rc9196">
					<xsl:variable name="Uitkeringen" select="vz811:Uitkeringen"/>
					<xsl:if test="($Uitkeringen !='')">
						<xsl:call-template name="rc9196">
							<xsl:with-param name="MedischeZorgkosten" select="vz811:Uitkeringen/vz811:Kosten/vbt:MedischeZorgkosten"/>
							<xsl:with-param name="Medicijnkosten" select="vz811:Uitkeringen/vz811:Kosten/vbt:Medicijnkosten"/>
							<xsl:with-param name="Tandartskosten" select="vz811:Uitkeringen/vz811:Kosten/vbt:Tandartskosten"/>
							<xsl:with-param name="LangdurigeZorgkosten" select="vz811:Uitkeringen/vz811:Kosten/vbt:LangdurigeZorgkosten"/>
							<xsl:with-param name="Ziekenhuisopnameskosten" select="vz811:Uitkeringen/vz811:Kosten/vbt:Ziekenhuisopnameskosten"/>
							<xsl:with-param name="OverigeKosten" select="vz811:Uitkeringen/vz811:Kosten/vbt:OverigeKosten"/>
						</xsl:call-template>
					</xsl:if>	
				</xsl:variable>
				
				<!-- retourcode 9200: Einddatum moet gelijk zijn aan of vroeger zijn dan de verzenddatum. -->
				<xsl:variable name="rc9200">
					<xsl:call-template name="rc9200">
						<xsl:with-param name="Verzenddatum" select="$Verzenddatum"/>	
						<xsl:with-param name="Einddatum" select="translate(vz811:Uitkeringen/vz811:Periode/vbt:Einddatum, '-', '')"/>						
					</xsl:call-template>
				</xsl:variable>
				
				<xsl:copy-of select="$rc0350"/>
				<xsl:copy-of select="$rc9192"/>
				<xsl:copy-of select="$rc9196"/>		
				<xsl:copy-of select="$rc9200"/>	
					
				<!-- Wanneer de klasse correct is dan wordt een 0200 retourcode toegevoegd. -->
				<xsl:if test="$rc0350='' and $rc9192='' and $rc9196='' and $rc9200=''">
					<vbt:Retourcode>0200</vbt:Retourcode>
				</xsl:if>
				
			</vz812:Retourcodes>
  	       	
		</vz812:Specificatieregel>
	</xsl:template>		
	
	<xsl:template match="vbt:CrediteurOrgaan">	
		<vbt:CrediteurOrgaan>
			<xsl:apply-templates select="vbt:Orgaancode" mode="copy-if-exists"/>
			<xsl:apply-templates select="vbt:Landcode" mode="copy-if-exists"/>
			<xsl:apply-templates select="vbt:Naam" mode="copy-if-exists"/>
		</vbt:CrediteurOrgaan>
	</xsl:template>
	
	<xsl:template match="vbt:BuitenlandsVerbindingsOrgaan">	
		<vbt:BuitenlandsVerbindingsOrgaan>
			<xsl:apply-templates select="vbt:Orgaancode" mode="copy-if-exists"/>
			<xsl:apply-templates select="vbt:Landcode" mode="copy-if-exists"/>
			<xsl:apply-templates select="vbt:Naam" mode="copy-if-exists"/>
		</vbt:BuitenlandsVerbindingsOrgaan>
	</xsl:template>

	<xsl:template match="vz811:DebiteurOrgaan">	
		<vz812:DebiteurOrgaan>
			<xsl:apply-templates select="vbt:Orgaancode" mode="copy-if-exists"/>
			<xsl:apply-templates select="vbt:Landcode" mode="copy-if-exists"/>
			<xsl:apply-templates select="vbt:Naam" mode="copy-if-exists"/>
		</vz812:DebiteurOrgaan>
	</xsl:template>
	
	<xsl:template match="vz811:TotaalBedragSpecificaties">	
		<vz812:TotaalBedragSpecificaties>
			<xsl:apply-templates select="vbt:Bedrag" mode="copy-if-exists"/>
			<xsl:apply-templates select="vbt:Valuta" mode="copy-if-exists"/>
		</vz812:TotaalBedragSpecificaties>
	</xsl:template>		
	
	<xsl:template match="vz811:Referenties">	
		<vz812:Referenties>
			<xsl:apply-templates select="vz811:DeclaratieregelReferentienummer" mode="copy-if-exists"/>
			<xsl:apply-templates select="vz811:CrediteringsregelReferentienummer" mode="copy-if-exists"/>
		</vz812:Referenties>
	</xsl:template>	

	<xsl:template match="vz811:Persoonsgegevens">	
		<vz812:Persoonsgegevens>
			<xsl:apply-templates select="vbt:PINVerzekeringsland" mode="copy-if-exists"/>
			<xsl:apply-templates select="vbt:PINWoonlandofVerblijfsland" mode="copy-if-exists"/>
			<xsl:apply-templates select="vbt:Familienaam" mode="copy-if-exists"/>
			<xsl:apply-templates select="vbt:FamilienaamGeboorte" mode="copy-if-exists"/>
			<xsl:apply-templates select="vbt:Voornamen" mode="copy-if-exists"/>
			<xsl:apply-templates select="vbt:VoornamenGeboorte" mode="copy-if-exists"/>
			<xsl:apply-templates select="vbt:Geboortedatum" mode="copy-if-exists"/>
			<xsl:apply-templates select="vbt:GeslachtCode" mode="copy-if-exists"/>
		</vz812:Persoonsgegevens>
	</xsl:template>		
		
	<xsl:template match="vz811:TotaalBedrag">	
		<vz812:TotaalBedrag>
			<xsl:apply-templates select="vbt:Bedrag" mode="copy-if-exists"/>
			<xsl:apply-templates select="vbt:Valuta" mode="copy-if-exists"/>
		</vz812:TotaalBedrag>
	</xsl:template>	
	
	<xsl:template match="vz811:Uitkeringen">	
		<vz812:Uitkeringen>
			<xsl:apply-templates select="vz811:SoortPrestatie" mode="copy-if-exists"/>
			<xsl:apply-templates select="vz811:DatumAWOD" mode="copy-if-exists"/>
			<xsl:apply-templates select="vz811:Periode"/>
			<xsl:apply-templates select="vz811:Kosten"/>
		</vz812:Uitkeringen>
	</xsl:template>		

	<xsl:template match="vz811:Periode">	
		<vz812:Periode>
			<xsl:apply-templates select="vbt:Begindatum" mode="copy-if-exists"/>
			<xsl:apply-templates select="vbt:Einddatum" mode="copy-if-exists"/>
		</vz812:Periode>
	</xsl:template>		
		
	<xsl:template match="vz811:Kosten">	
		<vz812:Kosten>
			<xsl:apply-templates select="vbt:MedischeZorgkosten"/>
			<xsl:apply-templates select="vbt:Medicijnkosten"/>
			<xsl:apply-templates select="vbt:Tandartskosten"/>
			<xsl:apply-templates select="vbt:LangdurigeZorgkosten"/>
			<xsl:apply-templates select="vbt:Ziekenhuisopnameskosten"/>
			<xsl:apply-templates select="vbt:OverigeKosten"/>
		</vz812:Kosten>
	</xsl:template>		

	<xsl:template match="vbt:MedischeZorgkosten">	
		<vbt:MedischeZorgkosten>
			<xsl:apply-templates select="vbt:Bedrag" mode="copy-if-exists"/>
		</vbt:MedischeZorgkosten>
	</xsl:template>	
	
	<xsl:template match="vbt:Medicijnkosten">	
		<vbt:Medicijnkosten>
			<xsl:apply-templates select="vbt:Bedrag" mode="copy-if-exists"/>
		</vbt:Medicijnkosten>
	</xsl:template>	
	
	<xsl:template match="vbt:Tandartskosten">	
		<vbt:Tandartskosten>
			<xsl:apply-templates select="vbt:Bedrag" mode="copy-if-exists"/>
		</vbt:Tandartskosten>
	</xsl:template>	
	
	<xsl:template match="vbt:LangdurigeZorgkosten">	
		<vbt:LangdurigeZorgkosten>
			<xsl:apply-templates select="vbt:Bedrag" mode="copy-if-exists"/>
		</vbt:LangdurigeZorgkosten>
	</xsl:template>	
	
	<xsl:template match="vbt:Periode">	
		<vbt:Periode>
			<xsl:apply-templates select="vbt:Begindatum" mode="copy-if-exists"/>
			<xsl:apply-templates select="vbt:Einddatum" mode="copy-if-exists"/>
		</vbt:Periode>
	</xsl:template>	
	
		<xsl:template match="vbt:Ziekenhuisopnameskosten">	
		<vbt:Ziekenhuisopnameskosten>
			<xsl:apply-templates select="vbt:UitkeringZiekenhuisopname"/>
		</vbt:Ziekenhuisopnameskosten>
	</xsl:template>

	<xsl:template match="vbt:UitkeringZiekenhuisopname">	
		<vbt:UitkeringZiekenhuisopname>
			<xsl:apply-templates select="vbt:Periode"/>
			<xsl:apply-templates select="vbt:Kosten"/>
		</vbt:UitkeringZiekenhuisopname>
	</xsl:template>		
	
	<xsl:template match="vbt:Kosten">	
		<vbt:Kosten>
			<xsl:apply-templates select="vbt:Bedrag" mode="copy-if-exists"/>
		</vbt:Kosten>
	</xsl:template>	

		<xsl:template match="vbt:OverigeKosten">	
		<vbt:OverigeKosten>
			<xsl:apply-templates select="vbt:UitkeringOverig"/>
		</vbt:OverigeKosten>
	</xsl:template>

	<xsl:template match="vbt:UitkeringOverig">	
		<vbt:UitkeringOverig>
			<xsl:apply-templates select="vbt:Beschrijving" mode="copy-if-exists"/>
			<xsl:apply-templates select="vbt:Kosten"/>
		</vbt:UitkeringOverig>
	</xsl:template>	

	<!-- Copy template: als een enkel element voorkomt is, wordt deze gekopieerd in de opgegeven namespace -->
	<xsl:template match="vz811:*" mode="copy-if-exists">
		<xsl:param name="NameSpacePrefix" select="'vz812:'"/>
		<xsl:if test=".">
			<xsl:element name="{concat($NameSpacePrefix,local-name())}">
				<xsl:value-of select="text()"/>
			</xsl:element>
		</xsl:if>
	</xsl:template>
	<xsl:template match="*[not(starts-with(name(), 'vz811:'))]" mode="copy-if-exists">
        <xsl:if test=".">
            <xsl:element name="{name()}">
				<xsl:value-of select="text()"/>
            </xsl:element>
        </xsl:if>
	</xsl:template>

</xsl:stylesheet>